From 8128aa174f76646eedbf94c3f03cf1cff0f304d0 Mon Sep 17 00:00:00 2001
From: Pavel Shlyak <p.shlyak@pantherx.org>
Date: Thu, 26 May 2022 21:00:51 +0300
Subject: [PATCH] Image API: support FAT32 partitions

---
 gnu/build/image.scm  | 10 ++++++----
 gnu/system/image.scm |  9 +++++++--
 2 files changed, 13 insertions(+), 6 deletions(-)

diff --git a/gnu/build/image.scm b/gnu/build/image.scm
index 3e8b94e2d6..d1398144a5 100644
--- a/gnu/build/image.scm
+++ b/gnu/build/image.scm
@@ -95,12 +95,12 @@ (define* (make-ext-image partition target root
                            (estimate-partition-size root)
                            size)))))))
 
-(define* (make-vfat-image partition target root)
+(define* (make-vfat-image partition target root fs_bits)
   "Handle the creation of VFAT partition images.  See 'make-partition-image'."
   (let ((size (partition-size partition))
         (label (partition-label partition)))
     (invoke "fakeroot" "mkdosfs" "-n" label "-C" target
-            "-F" "16" "-S" "1024"
+            "-F" (number->string fs_bits) "-S" "1024"
             (size-in-kib
              (if (eq? size 'guess)
                  (estimate-partition-size root)
@@ -120,8 +120,10 @@ (define* (make-partition-image partition-sexp target root)
     (cond
      ((string-prefix? "ext" type)
       (make-ext-image partition target root))
-     ((string=? type "vfat")
-      (make-vfat-image partition target root))
+     ((or (string=? type "vfat") (string=? type "fat16"))
+      (make-vfat-image partition target root 16))
+     ((string=? type "fat32")
+      (make-vfat-image partition target root 32))
      (else
       (raise (condition
               (&message
diff --git a/gnu/system/image.scm b/gnu/system/image.scm
index dd32e58c2d..7e45f750d9 100644
--- a/gnu/system/image.scm
+++ b/gnu/system/image.scm
@@ -312,7 +312,8 @@ (define (partition->dos-type partition)
         (cond
          ((member 'esp flags) "0xEF")
          ((string-prefix? "ext" file-system) "0x83")
-         ((string=? file-system "vfat") "0x0E")
+         ((or (string=? file-system "vfat") (string=? file-system "fat16")) "0x0E")
+         ((string=? file-system "fat32") "0x0C")
          (else
           (raise (condition
                   (&message
@@ -329,7 +330,11 @@ (define (partition->gpt-type partition)
         (cond
          ((member 'esp flags) "U")
          ((string-prefix? "ext" file-system) "L")
-         ((string=? file-system "vfat") "F")
+         (
+          (or (string=? file-system "vfat")
+              (string=? file-system "fat16")
+              (string=? file-system "fat32")
+              ) "F")
          (else
           (raise (condition
                   (&message
-- 
2.32.1 (Apple Git-133)

